@@ -1,4 +1,4 @@
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -39,14 +39,15 @@ from . import (
 
 from .build import SconsInterface
 
-from .codegen import CodeGeneration
+from .codegen import CodeGeneration, ConstantCodes
 
 from .optimizations import Optimization
 from .finalizations import Finalization
 
 from nuitka.freezer.Standalone import (
     detectEarlyImports,
-    detectPythonDLLs
+    detectLateImports,
+    detectUsedDLLs
 )
 from nuitka.freezer.BytecodeModuleFreezer import (
     generateBytecodeFrozenCode,
@@ -56,9 +57,9 @@ from nuitka.freezer.BytecodeModuleFreezer import (
 
 import sys, os, subprocess, shutil
 
-from logging import warning
+from logging import warning, info
 
-def createNodeTree( filename ):
+def createNodeTree(filename):
     """ Create a node tree.
 
     Turn that source code into a node tree structure. If recursion into
@@ -74,19 +75,22 @@ def createNodeTree( filename ):
         is_top   = True,
         is_main  = not Options.shallMakeModule()
     )
-    ModuleRegistry.addRootModule( main_module )
+    ModuleRegistry.addRootModule(main_module)
 
     # First remove old object files and old generated files, old binary or
     # module, and standalone mode program directory if any, they can only do
     # harm.
-    source_dir = getSourceDirectoryPath( main_module )
-    cleanSourceDirectory( source_dir )
+    source_dir = getSourceDirectoryPath(main_module)
+
+    if not Options.shallOnlyExecCppCall():
+        cleanSourceDirectory(source_dir)
+
     if Options.isStandaloneMode():
-        standalone_dir = getStandaloneDirectoryPath( main_module )
-        shutil.rmtree( standalone_dir, ignore_errors = True )
-        Utils.makePath( standalone_dir )
+        standalone_dir = getStandaloneDirectoryPath(main_module)
+        shutil.rmtree(standalone_dir, ignore_errors = True)
+        Utils.makePath(standalone_dir)
     Utils.deleteFile(
-        path       = getResultFullpath( main_module ),
+        path       = getResultFullpath(main_module),
         must_exist = False
     )
 
@@ -102,7 +106,7 @@ def createNodeTree( filename ):
 
     return main_module
 
-def dumpTree( tree ):
+def dumpTree(tree):
     Tracing.printLine( "Analysis -> Tree Result" )
 
     Tracing.printSeparator()
@@ -115,21 +119,21 @@ def dumpTree( tree ):
     Tracing.printSeparator()
     Tracing.printSeparator()
 
-def dumpTreeXML( tree ):
+def dumpTreeXML(tree):
     xml_root = tree.asXml()
-    TreeXML.dump( xml_root )
+    TreeXML.dump(xml_root)
 
-def displayTree( tree ):
+def displayTree(tree):
     # Import only locally so the Qt4 dependency doesn't normally come into play
     # when it's not strictly needed, pylint: disable=W0404
     from .gui import TreeDisplay
 
-    TreeDisplay.displayTreeInspector( tree )
+    TreeDisplay.displayTreeInspector(tree)
 
-def getTreeFilenameWithSuffix( tree, suffix ):
+def getTreeFilenameWithSuffix(tree, suffix):
     return tree.getOutputFilename() + suffix
 
-def getSourceDirectoryPath( main_module ):
+def getSourceDirectoryPath(main_module):
     assert main_module.isPythonModule()
 
     return Options.getOutputPath(
@@ -138,7 +142,7 @@ def getSourceDirectoryPath( main_module ):
         )
     )
 
-def getStandaloneDirectoryPath( main_module ):
+def getStandaloneDirectoryPath(main_module):
     return Options.getOutputPath(
         path = Utils.basename(
             getTreeFilenameWithSuffix( main_module, ".dist" )
@@ -146,7 +150,7 @@ def getStandaloneDirectoryPath( main_module ):
     )
 
 
-def getResultBasepath( main_module ):
+def getResultBasepath(main_module):
     assert main_module.isPythonModule()
 
     if Options.isStandaloneMode():
@@ -167,7 +171,7 @@ def getResultFullpath(main_module):
     result = getResultBasepath(main_module)
 
     if Options.shallMakeModule():
-        if Options.isWindowsTarget():
+        if Utils.getOS() == "Windows":
             result += ".pyd"
         else:
             result += ".so"
@@ -176,47 +180,56 @@ def getResultFullpath(main_module):
 
     return result
 
-def cleanSourceDirectory( source_dir ):
-    if Utils.isDir( source_dir ):
-        for path, _filename in Utils.listDir( source_dir ):
-            if Utils.getExtension( path ) in ( ".cpp", ".hpp", ".o", ".os" ):
-                Utils.deleteFile( path, True )
+def cleanSourceDirectory(source_dir):
+    if Utils.isDir(source_dir):
+        for path, _filename in Utils.listDir(source_dir):
+            if Utils.getExtension(path) in (".cpp", ".hpp", ".c", ".o", ".os",
+                                            ".obj", ".bin", ".res", ".rc",
+                                            ".manifest"):
+                Utils.deleteFile(path, True)
     else:
         Utils.makePath( source_dir )
 
-    static_source_dir = Utils.joinpath( source_dir, "static" )
+    static_source_dir = Utils.joinpath(
+        source_dir,
+        "static"
+    )
 
-    if Utils.isDir( static_source_dir ):
-        for path, _filename in sorted( Utils.listDir( static_source_dir ) ):
-            if Utils.getExtension( path ) in ( ".o", ".os" ):
-                Utils.deleteFile( path, True )
+    if Utils.isDir(static_source_dir):
+        for path, _filename in Utils.listDir(static_source_dir):
+            if Utils.getExtension(path) in (".o", ".os", ".obj"):
+                Utils.deleteFile(path, True)
 
-def pickSourceFilenames( source_dir, modules ):
+
+def pickSourceFilenames(source_dir, modules):
     collision_filenames = set()
     seen_filenames = set()
 
-    for module in sorted( modules, key = lambda x : x.getFullName() ):
-        base_filename = Utils.joinpath( source_dir, module.getFullName() )
+    for module in sorted(modules, key = lambda x : x.getFullName()):
+        base_filename = Utils.joinpath(source_dir, module.getFullName())
 
         # Note: Could detect if the filesystem is cases sensitive in source_dir
         # or not, but that's probably not worth the effort.
         collision_filename = Utils.normcase( base_filename )
 
         if collision_filename in seen_filenames:
-            collision_filenames.add( collision_filename )
+            collision_filenames.add(collision_filename)
 
-        seen_filenames.add( collision_filename )
+        seen_filenames.add(collision_filename)
 
     collision_counts = {}
 
     module_filenames = {}
 
-    for module in sorted( modules, key = lambda x : x.getFullName() ):
+    for module in sorted(modules, key = lambda x : x.getFullName()):
+        if module.isPythonShlibModule():
+            continue
+
         base_filename = Utils.joinpath(
             source_dir,
             "module." + module.getFullName()
-              if not module.isInternalModule()
-            else module.getFullName()
+              if not module.isInternalModule() else
+            module.getFullName()
         )
 
         collision_filename = Utils.normcase( base_filename )
@@ -233,15 +246,15 @@ def pickSourceFilenames( source_dir, modules ):
         cpp_filename = base_filename + ".cpp"
         hpp_filename = base_filename + ".hpp"
 
-        module_filenames[ module ] = ( cpp_filename, hpp_filename )
+        module_filenames[module] = (cpp_filename, hpp_filename)
 
     return module_filenames
 
 standalone_entry_points = []
 
-def makeSourceDirectory( main_module ):
+def makeSourceDirectory(main_module):
     # We deal with a lot of details here, but rather one by one, and split makes
-    # no sense, pylint: disable=R0914
+    # no sense, pylint: disable=R0914,R0912
 
     assert main_module.isPythonModule()
 
@@ -255,7 +268,8 @@ def makeSourceDirectory( main_module ):
     # Sometimes we need to talk about all modules except main module.
     other_modules = ModuleRegistry.getDoneUserModules()
 
-    # Lets check if the recurse-to modules are actually present.
+    # Lets check if the recurse-to modules are actually present, and warn the
+    # user if one was not found.
     for any_case_module in Options.getShallFollowModules():
         for module in other_modules:
             if module.getFullName() == any_case_module:
@@ -267,12 +281,12 @@ def makeSourceDirectory( main_module ):
             )
 
     # Prepare code generation, i.e. execute finalization for it.
-    for module in sorted( modules, key = lambda x : x.getFullName() ):
+    for module in sorted(modules, key = lambda x : x.getFullName()):
         if module.isPythonModule():
-            Finalization.prepareCodeGeneration( module )
+            Finalization.prepareCodeGeneration(module)
 
     # Pick filenames.
-    source_dir = getSourceDirectoryPath( main_module )
+    source_dir = getSourceDirectoryPath(main_module)
 
     module_filenames = pickSourceFilenames(
         source_dir = source_dir,
@@ -281,10 +295,10 @@ def makeSourceDirectory( main_module ):
 
     module_hpps = []
 
-    for module in sorted( modules, key = lambda x : x.getFullName() ):
-        cpp_filename, hpp_filename = module_filenames[ module ]
-
+    for module in sorted(modules, key = lambda x : x.getFullName()):
         if module.isPythonModule():
+            cpp_filename, hpp_filename = module_filenames[module]
+
             source_code, header_code, module_context = \
               CodeGeneration.generateModuleCode(
                   global_context = global_context,
@@ -313,28 +327,34 @@ def makeSourceDirectory( main_module ):
                 filename     = hpp_filename,
                 source_code  = header_code
             )
+
+            if Options.isShowInclusion():
+                info("Included compiled module '%s'.", module.getFullName())
+
         elif module.isPythonShlibModule():
             target_filename = Utils.joinpath(
-                getStandaloneDirectoryPath( main_module ),
-                *module.getFullName().split( "." )
+                getStandaloneDirectoryPath(main_module),
+                *module.getFullName().split(".")
             )
 
-            if Options.isWindowsTarget():
+            if Utils.getOS() == "Windows":
                 target_filename += ".pyd"
             else:
                 target_filename += ".so"
 
-            target_dir = Utils.dirname( target_filename )
+            target_dir = Utils.dirname(target_filename)
 
-            if not Utils.isDir( target_dir ):
-                Utils.makePath( target_dir )
+            if not Utils.isDir(target_dir):
+                Utils.makePath(target_dir)
 
             shutil.copy(
                 module.getFilename(),
                 target_filename
             )
 
-            standalone_entry_points.append( target_filename )
+            standalone_entry_points.append(
+                (target_filename,module.getPackage())
+            )
         else:
             assert False, module
 
@@ -375,108 +395,115 @@ def makeSourceDirectory( main_module ):
         source_code = "".join( module_hpp_include )
     )
 
-def runScons( main_module, quiet ):
+def runScons(main_module, quiet):
     # Scons gets transported many details, that we express as variables, and
     # have checks for them, leading to many branches, pylint: disable=R0912
 
     python_version = "%d.%d" % ( sys.version_info[0], sys.version_info[1] )
 
-    if hasattr( sys, "abiflags" ):
+    if hasattr(sys, "abiflags"):
         # The Python3 for some platforms has sys.abiflags pylint: disable=E1101
         if Options.isPythonDebug() or \
-           hasattr( sys, "getobjects" ):
-            if sys.abiflags.startswith( "d" ):
+           hasattr(sys, "getobjects"):
+            if sys.abiflags.startswith("d"):
                 python_version += sys.abiflags
             else:
                 python_version += "d" + sys.abiflags
         else:
             python_version += sys.abiflags
 
-    def asBoolStr( value ):
+    def asBoolStr(value):
         return "true" if value else "false"
 
     options = {
         "name"           : Utils.basename(
-            getTreeFilenameWithSuffix( main_module, "" )
+            getTreeFilenameWithSuffix(main_module, "")
         ),
-        "result_name"    : getResultBasepath( main_module ),
-        "source_dir"     : getSourceDirectoryPath( main_module ),
-        "debug_mode"     : asBoolStr( Options.isDebug() ),
-        "python_debug"   : asBoolStr( Options.isPythonDebug() ),
-        "unstriped_mode" : asBoolStr( Options.isUnstriped() ),
-        "module_mode"    : asBoolStr( Options.shallMakeModule() ),
-        "optimize_mode"  : asBoolStr( Options.isOptimize() ),
-        "full_compat"    : asBoolStr( Options.isFullCompat() ),
-        "experimental"   : asBoolStr( Options.isExperimental() ),
+        "result_name"    : getResultBasepath(main_module),
+        "source_dir"     : getSourceDirectoryPath(main_module),
+        "debug_mode"     : asBoolStr(Options.isDebug()),
+        "python_debug"   : asBoolStr(Options.isPythonDebug()),
+        "unstriped_mode" : asBoolStr(Options.isUnstriped()),
+        "module_mode"    : asBoolStr(Options.shallMakeModule()),
+        "optimize_mode"  : asBoolStr(Options.isOptimize()),
+        "full_compat"    : asBoolStr(Options.isFullCompat()),
+        "experimental"   : asBoolStr(Options.isExperimental()),
         "python_version" : python_version,
         "target_arch"    : Utils.getArchitecture(),
         "python_prefix"  : sys.prefix,
         "nuitka_src"     : SconsInterface.getSconsDataPath(),
         "module_count"   : "%d" % (
-            len( ModuleRegistry.getDoneUserModules() ) + 1
+            len(ModuleRegistry.getDoneUserModules()) + 1
         )
     }
 
     # Ask Scons to cache on Windows, except where the directory is thrown
     # away. On non-Windows you can should use ccache instead.
-    if not Options.isRemoveBuildDir() and os.name == "nt":
-        options[ "cache_mode" ] = "true"
+    if not Options.isRemoveBuildDir() and Utils.getOS() == "Windows":
+        options["cache_mode"] = "true"
 
     if Options.isLto():
-        options[ "lto_mode" ] = "true"
-
-    if Options.isWindowsTarget():
-        options[ "win_target" ] = "true"
+        options["lto_mode"] = "true"
 
     if Options.shallDisableConsoleWindow():
-        options[ "win_disable_console" ] = "true"
+        options["win_disable_console"] = "true"
 
     if Options.isStandaloneMode():
-        options[ "standalone_mode" ] = "true"
+        options["standalone_mode"] = "true"
 
     if getFrozenModuleCount():
-        options[ "frozen_modules" ] = str(
+        options["frozen_modules"] = str(
             getFrozenModuleCount()
         )
 
     if Options.isShowScons():
-        options[ "show_scons" ] = "true"
+        options["show_scons"] = "true"
 
     if Options.isMingw():
-        options[ "mingw_mode" ] = "true"
+        options["mingw_mode"] = "true"
 
     if Options.isClang():
-        options[ "clang_mode" ] = "true"
+        options["clang_mode"] = "true"
 
     if Options.getIconPath():
-        options[ "icon_path" ] = Options.getIconPath()
+        options["icon_path"] = Options.getIconPath()
 
     return SconsInterface.runScons( options, quiet ), options
 
-def writeSourceCode( filename, source_code ):
+def writeSourceCode(filename, source_code):
     # Prevent accidental overwriting. When this happens the collision detection
     # or something else has failed.
-    assert not Utils.isFile( filename ), filename
+    assert not Utils.isFile(filename), filename
 
     if Utils.python_version >= 300:
-        with open( filename, "wb" ) as output_file:
-            output_file.write( source_code.encode( "latin1" ) )
+        with open(filename, "wb") as output_file:
+            output_file.write(source_code.encode("latin1"))
     else:
-        with open( filename, "w" ) as output_file:
-            output_file.write( source_code )
+        with open(filename, "w") as output_file:
+            output_file.write(source_code)
+
+def writeBinaryData(filename, binary_data):
+    # Prevent accidental overwriting. When this happens the collision detection
+    # or something else has failed.
+    assert not Utils.isFile(filename), filename
+
+    assert type(binary_data) is bytes
+
+    with open(filename, "wb") as output_file:
+        output_file.write(binary_data)
 
 
-def callExec( args, clean_path, add_path ):
-    old_python_path = os.environ.get( "PYTHONPATH", None )
+def callExec(args, clean_path, add_path):
+    old_python_path = os.environ.get("PYTHONPATH", None)
 
     if clean_path and old_python_path is not None:
-        os.environ[ "PYTHONPATH" ] = ""
+        os.environ["PYTHONPATH"] = ""
 
     if add_path:
-        os.environ[ "PYTHONPATH" ] = \
-          os.environ.get( "PYTHONPATH", "" ) + \
-          ":" + \
-          Options.getOutputDir()
+        if "PYTHONPATH" in os.environ:
+            os.environ["PYTHONPATH"] += ":" + Options.getOutputDir()
+        else:
+            os.environ["PYTHONPATH"] = Options.getOutputDir()
 
     # We better flush these, "os.execl" won't do it anymore.
     sys.stdout.flush()
@@ -485,9 +512,9 @@ def callExec( args, clean_path, add_path ):
     args += Options.getMainArgs()
 
     # That's the API of execl, pylint: disable=W0142
-    Utils.callExec( args )
+    Utils.callExec(args)
 
-def executeMain( binary_filename, tree, clean_path ):
+def executeMain(binary_filename, tree, clean_path):
     main_filename = tree.getFilename()
 
     if Options.isStandaloneMode():
@@ -497,12 +524,9 @@ def executeMain( binary_filename, tree, clean_path ):
     else:
         name = main_filename
 
-    name = os.path.abspath( name )
+    name = Utils.abspath(name)
 
-    if Options.isWindowsTarget() and os.name != "nt":
-        args = ( "/usr/bin/wine", "wine", binary_filename )
-    else:
-        args = ( binary_filename, name )
+    args = (binary_filename, name)
 
     callExec(
         clean_path = clean_path,
@@ -510,10 +534,10 @@ def executeMain( binary_filename, tree, clean_path ):
         args       = args
     )
 
-def executeModule( tree, clean_path ):
-    python_command = "__import__( '%s' )" % tree.getName()
+def executeModule(tree, clean_path):
+    python_command = "__import__('%s')" % tree.getName()
 
-    if os.name == "nt":
+    if Utils.getOS() == "Windows":
         python_command = '"%s"' % python_command
 
     args = (
@@ -529,18 +553,18 @@ def executeModule( tree, clean_path ):
         args       = args
     )
 
-def compileTree( main_module ):
-    source_dir = getSourceDirectoryPath( main_module )
+def compileTree(main_module):
+    source_dir = getSourceDirectoryPath(main_module)
 
-    if not Options.shallOnlyExecGcc():
+    if not Options.shallOnlyExecCppCall():
         # Now build the target language code for the whole tree.
         makeSourceDirectory(
             main_module = main_module
         )
 
         if Options.isStandaloneMode():
-            for early_import in detectEarlyImports():
-                addFrozenModule( early_import )
+            for late_import in detectLateImports():
+                addFrozenModule(late_import)
 
         if getFrozenModuleCount():
             frozen_code = generateBytecodeFrozenCode()
@@ -552,12 +576,23 @@ def compileTree( main_module ):
                 ),
                 source_code = frozen_code
             )
+
+        writeBinaryData(
+            filename    = Utils.joinpath(source_dir, "__constants.bin"),
+            binary_data = ConstantCodes.stream_data.getBytes()
+        )
     else:
-        source_dir = getSourceDirectoryPath( main_module )
+        source_dir = getSourceDirectoryPath(main_module)
 
-        if not Utils.isFile( Utils.joinpath( source_dir, "__helpers.hpp" ) ):
-            sys.exit( "Error, no previous build directory exists." )
+        if not Utils.isFile( Utils.joinpath(source_dir, "__helpers.hpp")):
+            sys.exit("Error, no previous build directory exists.")
 
+    if Options.isShowProgress():
+        Tracing.printLine(
+            """Total memory usage before running scons: {memory}:""".format(
+                memory      = Utils.getHumanReadableProcessMemoryUsage()
+            )
+        )
 
     # Run the Scons to build things.
     result, options = runScons(
@@ -589,9 +624,15 @@ def main():
     # Inform the importing layer about the main script directory, so it can use
     # it when attempting to follow imports.
     Importing.setMainScriptDirectory(
-        main_dir = os.path.dirname( os.path.abspath( filename ) )
+        main_dir = Utils.dirname(Utils.abspath(filename))
     )
 
+    # Detect to be frozen modules if any, so we can consider to not recurse
+    # to them.
+    if Options.isStandaloneMode():
+        for early_import in detectEarlyImports():
+            addFrozenModule(early_import)
+
     # Turn that source code into a node tree structure.
     try:
         main_module = createNodeTree(
@@ -599,7 +640,7 @@ def main():
         )
     except (SyntaxError, IndentationError) as e:
         if Options.isFullCompat() and \
-           e.args[0].startswith( "unknown encoding:" ):
+           e.args[0].startswith("unknown encoding:"):
             if Utils.python_version >= 333 or \
                (
                    Utils.python_version >= 276 and \
@@ -613,60 +654,65 @@ def main():
 
             e.args = (
                 "encoding problem: %s" % complaint,
-                ( e.args[1][0], 1, None, None )
+                (e.args[1][0], 1, None, None)
             )
 
-        sys.exit( SyntaxErrors.formatOutput( e ) )
+        sys.exit(
+            SyntaxErrors.formatOutput(e)
+        )
 
     if Options.shallDumpBuiltTree():
-        dumpTree( main_module )
+        dumpTree(main_module)
     elif Options.shallDumpBuiltTreeXML():
-        dumpTreeXML( main_module )
+        dumpTreeXML(main_module)
     elif Options.shallDisplayBuiltTree():
-        displayTree( main_module )
+        displayTree(main_module)
     else:
-        result, options = compileTree( main_module )
+        result, options = compileTree(
+            main_module = main_module
+        )
 
         # Exit if compilation failed.
         if not result:
-            sys.exit( 1 )
+            sys.exit(1)
 
         # Remove the source directory (now build directory too) if asked to.
         if Options.isRemoveBuildDir():
-            shutil.rmtree( getSourceDirectoryPath( main_module ) )
+            shutil.rmtree(
+                getSourceDirectoryPath(main_module)
+            )
 
         if Options.isStandaloneMode():
-            binary_filename = options[ "result_name" ] + ".exe"
+            binary_filename = options["result_name"] + ".exe"
 
-            standalone_entry_points.append( binary_filename )
+            standalone_entry_points.insert(
+                0,
+                (binary_filename, None)
+            )
 
-            for early_dll in detectPythonDLLs( standalone_entry_points ):
+            if Utils.getOS() == "NetBSD":
+                warning("Standalone mode on NetBSD is not functional, due to $ORIGIN linkage not being supported.")
+
+            for early_dll in detectUsedDLLs(standalone_entry_points):
                 shutil.copy(
                     early_dll,
                     Utils.joinpath(
-                        getStandaloneDirectoryPath( main_module ),
-                        Utils.basename( early_dll )
+                        getStandaloneDirectoryPath(main_module),
+                        Utils.basename(early_dll)
                     )
                 )
 
-        # Sanity check, warn people if "__main__" is used in the compiled
-        # module, it may not be the appropiate usage.
-        if Options.shallMakeModule() and Options.shallExecuteImmediately():
-            for variable in main_module.getVariables():
-                if variable.getName() == "__name__":
-                    warning( """\
-Compiling to extension module, which will not have '__name__' as '__main__', \
-did you intend '--exe' or to use 'nuitka-python' instead.""" )
-                    break
+                if Options.isShowInclusion():
+                    info("Included used shared library '%s'.", early_dll)
 
         # Modules should not be executable, but Scons creates them like it, fix
         # it up here.
-        if os.name != "nt" and Options.shallMakeModule():
+        if Utils.getOS() != "Windows" and Options.shallMakeModule():
             subprocess.call(
                 (
                     "chmod",
                     "-x",
-                    getResultFullpath( main_module )
+                    getResultFullpath(main_module)
                 )
             )
 
@@ -679,7 +725,7 @@ did you intend '--exe' or to use 'nuitka-python' instead.""" )
                 )
             else:
                 executeMain(
-                    binary_filename = getResultFullpath( main_module ),
+                    binary_filename = getResultFullpath(main_module),
                     tree            = main_module,
                     clean_path      = Options.shallClearPythonPathEnvironment()
                 )
