@@ -1,4 +1,4 @@
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -163,7 +163,7 @@ if ( args_given > %(top_level_parameter_count)d )
 }
 else
 {
-    _python_par_%(list_star_parameter_name)s = INCREASE_REFCOUNT( _python_tuple_empty );
+    _python_par_%(list_star_parameter_name)s = INCREASE_REFCOUNT( const_tuple_empty );
 }
 """
 
@@ -479,7 +479,7 @@ if (unlikely( %(parameter_test)s ))
 template_dparser = """
 static PyObject *dparse_%(function_identifier)s( Nuitka_FunctionObject *self, PyObject **args, int size )
 {
-    if ( size == %(arg_count)d)
+    if ( size == %(arg_count)d )
     {
         return impl_%(function_identifier)s( self%(args_forward)s );
     }
