@@ -1,4 +1,4 @@
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -25,12 +25,12 @@ from .NodeBases import (
 )
 
 
-class ExpressionListOperationAppend( ExpressionChildrenHavingBase ):
+class ExpressionListOperationAppend(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_LIST_OPERATION_APPEND"
 
     named_children = ( "list", "value" )
 
-    def __init__( self, liste, value, source_ref ):
+    def __init__(self, liste, value, source_ref):
         assert liste is not None
         assert value is not None
 
@@ -46,18 +46,18 @@ class ExpressionListOperationAppend( ExpressionChildrenHavingBase ):
     getList = ExpressionChildrenHavingBase.childGetter( "list" )
     getValue = ExpressionChildrenHavingBase.childGetter( "value" )
 
-    def computeExpression( self, constraint_collection ):
+    def computeExpression(self, constraint_collection):
         constraint_collection.removeKnowledge( self.getList() )
 
         return self, None, None
 
 
-class ExpressionSetOperationAdd( ExpressionChildrenHavingBase ):
+class ExpressionSetOperationAdd(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_SET_OPERATION_ADD"
 
     named_children = ( "set", "value" )
 
-    def __init__( self, sete, value, source_ref ):
+    def __init__(self, sete, value, source_ref):
         assert sete is not None
         assert value is not None
 
@@ -73,18 +73,18 @@ class ExpressionSetOperationAdd( ExpressionChildrenHavingBase ):
     getSet = ExpressionChildrenHavingBase.childGetter( "set" )
     getValue = ExpressionChildrenHavingBase.childGetter( "value" )
 
-    def computeExpression( self, constraint_collection ):
+    def computeExpression(self, constraint_collection):
         constraint_collection.removeKnowledge( self.getSet() )
 
         return self, None, None
 
 
-class ExpressionDictOperationSet( ExpressionChildrenHavingBase ):
+class ExpressionDictOperationSet(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_DICT_OPERATION_SET"
 
     named_children = ( "dict", "key", "value" )
 
-    def __init__( self, dicte, key, value, source_ref ):
+    def __init__(self, dicte, key, value, source_ref):
         assert dicte is not None
         assert key is not None
         assert value is not None
@@ -103,18 +103,18 @@ class ExpressionDictOperationSet( ExpressionChildrenHavingBase ):
     getKey = ExpressionChildrenHavingBase.childGetter( "key" )
     getValue = ExpressionChildrenHavingBase.childGetter( "value" )
 
-    def computeExpression( self, constraint_collection ):
+    def computeExpression(self, constraint_collection):
         constraint_collection.removeKnowledge( self.getDict() )
 
         return self, None, None
 
 
-class StatementDictOperationRemove( StatementChildrenHavingBase ):
+class StatementDictOperationRemove(StatementChildrenHavingBase):
     kind = "STATEMENT_DICT_OPERATION_REMOVE"
 
     named_children = ( "dict", "key" )
 
-    def __init__( self, dicte, key, source_ref ):
+    def __init__(self, dicte, key, source_ref):
         assert dicte is not None
         assert key is not None
 
@@ -130,19 +130,21 @@ class StatementDictOperationRemove( StatementChildrenHavingBase ):
     getDict = StatementChildrenHavingBase.childGetter( "dict" )
     getKey = StatementChildrenHavingBase.childGetter( "key" )
 
-    def computeStatement( self, constraint_collection ):
+    def computeStatement(self, constraint_collection):
         constraint_collection.onExpression( self.getDict() )
         dicte = self.getDict()
 
         if dicte.willRaiseException( BaseException ):
-            from .NodeMakingHelpers import makeStatementExpressionOnlyReplacementNode
+            from .NodeMakingHelpers import \
+              makeStatementExpressionOnlyReplacementNode
 
             result = makeStatementExpressionOnlyReplacementNode(
                 expression = dicte,
                 node       = self
             )
 
-            return result, "new_raise", "Dictionary remove already raises implicitely accessing dictionary."
+            return result, "new_raise", """\
+Dictionary remove already raises implicitely accessing dictionary."""
 
         constraint_collection.onExpression( self.getKey() )
         key = self.getKey()
@@ -157,7 +159,8 @@ class StatementDictOperationRemove( StatementChildrenHavingBase ):
                 )
             )
 
-            return result, "new_node", "Dictionary remove already raises implicitely building key."
+            return result, "new_node", """
+Dictionary remove already raises implicitely building key."""
 
         # TODO: Be less lossly about it.
         constraint_collection.removeKnowledge( dicte )
@@ -166,12 +169,12 @@ class StatementDictOperationRemove( StatementChildrenHavingBase ):
 
 
 
-class ExpressionDictOperationGet( ExpressionChildrenHavingBase ):
+class ExpressionDictOperationGet(ExpressionChildrenHavingBase):
     kind = "EXPRESSION_DICT_OPERATION_GET"
 
     named_children = ( "dict", "key" )
 
-    def __init__( self, dicte, key, source_ref ):
+    def __init__(self, dicte, key, source_ref):
         assert dicte is not None
         assert key is not None
 
@@ -187,7 +190,7 @@ class ExpressionDictOperationGet( ExpressionChildrenHavingBase ):
     getDict = ExpressionChildrenHavingBase.childGetter( "dict" )
     getKey = ExpressionChildrenHavingBase.childGetter( "key" )
 
-    def computeExpression( self, constraint_collection ):
+    def computeExpression(self, constraint_collection):
         # Children can tell all we need to know, pylint: disable=W0613
 
         return self, None, None
